@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import os.path
 import re
+from typing import Any
 
 import pygments.lexer
 import pygments.token
@@ -49,15 +52,15 @@ STYLESHEET = '''\
 '''
 
 
-def stylesheet(colors=None):
+def stylesheet(colors: dict[str, str] | None = None) -> str:
     colors = colors or {}
     assert set(colors) <= set(COLORS), set(colors) - set(COLORS)
     colors = dict(COLORS, **colors)
     return STYLESHEET.format(**colors)
 
 
-def setup(app):  # pragma: no cover (sphinx)
-    def copy_stylesheet(app, exception):
+def setup(app: Any) -> dict[str, object]:  # pragma: no cover (sphinx)
+    def copy_stylesheet(app: Any, exception: BaseException | None) -> None:
         if exception:
             return
 
@@ -68,7 +71,11 @@ def setup(app):  # pragma: no cover (sphinx)
         with open(path, 'w') as f:
             f.write(stylesheet(app.config.pygments_pre_commit_ansi_colors))
 
-    app.require_sphinx('1.0')
+    app.require_sphinx('1.8')
     app.add_config_value('pygments_pre_commit_ansi_colors', {}, 'html')
-    app.add_stylesheet('pygments_pre_commit.css')
+    app.add_css_file('pygments_pre_commit.css')
     app.connect('build-finished', copy_stylesheet)
+    return {
+        'parallel_read_safe': True,
+        'parallel_write_safe': True,
+    }
